﻿using System;
using System.Windows;
using System.Windows.Input;

namespace CVB_TEST_ZOOM
{
  /// <summary>
  /// Logique d'interaction pour MainWindow.xaml
  /// </summary>

  public partial class MainWindow : Window
  {
    public MainWindow()
    {
      InitializeComponent();
    }

    private void Button_Click(object sender, RoutedEventArgs e)
    {
      try
      {
        Microsoft.Win32.OpenFileDialog openFileDialog = new Microsoft.Win32.OpenFileDialog();
        Nullable<bool> result = openFileDialog.ShowDialog();
        if (result == true)
        {
          disp_img.Image = Stemmer.Cvb.Image.FromFile(openFileDialog.FileName);
        }
      }
      catch (Exception)
      { }
    }

    private void Disp_img_MouseDoubleClick(object sender, MouseButtonEventArgs e)
    {
      // determine zoom factor to apply (current implementation: zoom in by
      // a factor of sqrt(2) when left double-clicking, zoom out by a factor
      // of sqrt(2) when right double-clicking).
      var zoomTarget = disp_img.ActualZoomFactor;
      if (e.LeftButton == MouseButtonState.Pressed)
        zoomTarget *= Math.Sqrt(2.0);
      else if (e.RightButton == MouseButtonState.Pressed)
        zoomTarget /= Math.Sqrt(2.0);
      else
        return;
      // zoom factor might become excessively large or small and Display does
      // not automatically apply an upper limit!
      if (zoomTarget > 64.0)
        zoomTarget = 64.0;
      if (zoomTarget < disp_img.StretchZoomFactor)
        zoomTarget = disp_img.StretchZoomFactor;        
      // the display will apply reasonable limits...      
      var zoomCenter = disp_img.TranslatePointToImage(e.MouseDevice.GetPosition(disp_img));
      disp_img.ZoomFactor = zoomTarget;
      disp_img.ZoomCenter = zoomCenter;
    }

    private void Slider_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
    {
      disp_img.ZoomCenter = new Point(SliderX.Value, SliderY.Value);
    }

    private void Disp_img_ZoomCenterChanged(object sender, Stemmer.Cvb.Wpf.Controls.DisplayZoomEventArgs e)
    {
      if (!double.IsNaN(e.ZoomCenter.X))
        SliderX.Value = e.ZoomCenter.X;
      if (!double.IsNaN(e.ZoomCenter.Y))
        SliderY.Value = e.ZoomCenter.Y;
    }

    private void Disp_img_PreviewMouseWheel(object sender, MouseWheelEventArgs e)
    {
      // stop mouse wheel event in its track...
      e.Handled = true;
    }
  }
}
